Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(338)

Unified Diff: components/offline_items_collection/core/android/offline_content_aggregator_bridge.h

Issue 2729983002: Attaches OfflineContentAggregator to Profile (Closed)
Patch Set: Address nit Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_items_collection/core/android/offline_content_aggregator_bridge.h
diff --git a/components/offline_items_collection/core/android/offline_content_aggregator_bridge.h b/components/offline_items_collection/core/android/offline_content_aggregator_bridge.h
index 89dc2a9606623e168ecbbf43d365ff5833817c1c..5a291c6f1d681ef9e0ee2c5e35fcc8ca3a0079bd 100644
--- a/components/offline_items_collection/core/android/offline_content_aggregator_bridge.h
+++ b/components/offline_items_collection/core/android/offline_content_aggregator_bridge.h
@@ -31,10 +31,10 @@ class OfflineContentAggregatorBridge : public OfflineContentProvider::Observer,
// Helper method to initialize the JNI hooks between Java and C++.
static bool Register(JNIEnv* env);
- // Returns an OfflineContentAggregatorBridge for |aggregator|. There will be
- // only one bridge per OfflineContentAggregator.
- static OfflineContentAggregatorBridge* GetForOfflineContentAggregator(
- OfflineContentAggregator* aggregator);
+ // Returns a Java OfflineContentAggregatorBridge for |aggregator|. There will
+ // be only one bridge per OfflineContentAggregator.
+ static base::android::ScopedJavaLocalRef<jobject>
+ GetBridgeForOfflineContentAggregator(OfflineContentAggregator* aggregator);
~OfflineContentAggregatorBridge() override;

Powered by Google App Engine
This is Rietveld 408576698